﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using Syncfusion.Windows.Controls.Grid;
using Syncfusion.Grouping;

namespace GroupingSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {

        private GroupingHelper groupingHelper;
        public Window1()
        {
             InitializeComponent();

            //get a datasource
             IEnumerable list = SampleData.GenerateSampleData(1000);

            //enable grouping support of the grid holding the datasource
             groupingHelper = new GroupingHelper(grid, list);

            //align all the cells right by default
             grid.Model.TableStyle.HorizontalAlignment = HorizontalAlignment.Right;

            //align the Name column to the left by setting its ColumnStyleInfo
             groupingHelper.ColumnStyles["Name"].Style.HorizontalAlignment = HorizontalAlignment.Left;

           //set the Headertext to something other than the column name
            groupingHelper.ColumnStyles["Col2"].HeaderText = "Column 2";

            //specify column order
            groupingHelper.VisibleColumns.Clear();
            groupingHelper.VisibleColumns.AddRange(new string[] { "Name", "Col4", "Col0", "Col1", "Col2", "Col3", "Col5", "Col6", "Col7", "Col8"});
            groupingHelper.ResetDisplay();

            ////only a few columns...
            //groupingHelper.VisibleColumns.Clear();
            //groupingHelper.VisibleColumns.AddRange(new string[] { "Name", "Col2", "Col3" });
            //groupingHelper.ResetDisplay();


            //set up some colors...

           //enable recordcellspanbackgrounds
            groupingHelper.RecordSpanInfoBrush = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45);

            //enable spacerSpansBackgrounds
            groupingHelper.SpacerSpanInfoBrush = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45); //new LinearGradientBrush(Colors.LightBlue, Colors.AliceBlue, 90);

            //set caption background
            groupingHelper.CellStyleForCaption.Background = new LinearGradientBrush(Colors.LightBlue, Colors.AliceBlue, 45);

            //set expand cell background
            groupingHelper.CellStyleForExpand.Background = new LinearGradientBrush(Colors.AliceBlue, Colors.LightBlue, 45);

            //set summary cell background
            groupingHelper.CellStyleForSummary.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummary.HorizontalAlignment = HorizontalAlignment.Right;
            groupingHelper.CellStyleForSummarySpacer.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummaryRowHeader.Background = Brushes.AliceBlue;
            groupingHelper.CellStyleForSummaryRowHeader.Borders.Right = null; //no border


            Brush b = new SolidColorBrush(Color.FromArgb(50, Colors.DodgerBlue.R, Colors.DodgerBlue.G, Colors.DodgerBlue.B));

            //columnheaders
            groupingHelper.CellStyleForColumnHeader.Background = b;
            groupingHelper.CellStyleForColumnHeaderRowHeader.Background = b;

            //rowheaders
            groupingHelper.CellStyleForRecordRowHeader.Background = b;
            groupingHelper.CellStyleForLastRecordRowHeader.Background = b;
            
            //addnew rowheader
            groupingHelper.CellStyleForAddNewRowHeader.Background = b;

            //caption rowheader
            groupingHelper.CellStyleForCaptionRowHeader.Background = b;

           //add some summaries
            SummaryDescriptor sd = new SummaryDescriptor("Col2", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col2", sd, false, "Sum"); //false indicates to hold off resetting the display
            sd = new SummaryDescriptor("Col1", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col1", sd, false, "Maximum");
            sd = new SummaryDescriptor("Name", SummaryType.Count);
            groupingHelper.SetSummary("Name", sd, false, "Count");
            sd = new SummaryDescriptor("Col0", SummaryType.Int32Aggregate);
            groupingHelper.SetSummary("Col0", sd, true, "Minimum"); //true indicates to reset the display

            //show summary row
            groupingHelper.ShowSummary = true;
            
            //group by Col3
            groupingHelper.ToggleGroupColumn("Col3");
            groupingHelper.ExpandAllGroups();
         }
    }
}
